@@ -44,6 +44,11 @@ module Data.HashPSQ
     , unsafeMapMonotonic
     , fold'
 
+      -- * Unsafe operations
+    , unsafeLookupIncreasePriority
+    , unsafeInsertIncreasePriority
+    , unsafeInsertIncreasePriorityView
+
       -- * Validity check
     , valid
     ) where
