@@ -1,4 +1,5 @@
 {-# LANGUAGE BangPatterns        #-}
+{-# LANGUAGE CPP                 #-}
 {-# LANGUAGE DeriveFoldable      #-}
 {-# LANGUAGE DeriveFunctor       #-}
 {-# LANGUAGE DeriveTraversable   #-}
@@ -74,7 +75,11 @@ import           Data.Foldable    (Foldable (foldr))
 import qualified Data.List        as List
 import           Data.Maybe       (isJust)
 import           Data.Traversable
+#if MIN_VERSION_base(4,11,0)
+import           Prelude          hiding (foldr, lookup, map, null, (<>))
+#else
 import           Prelude          hiding (foldr, lookup, map, null)
+#endif
 
 --------------------------------------------------------------------------------
 -- Types
@@ -305,7 +310,7 @@ toAscList q  = seqToList (toAscLists q)
     toAscLists t = case tourView t of
         Null             -> emptySequ
         Single (E k p v) -> singleSequ (k, p, v)
-        Play tl tr       -> toAscLists tl <> toAscLists tr
+        Play tl tr       -> toAscLists tl `appendSequ` toAscLists tr
 
 
 --------------------------------------------------------------------------------
@@ -693,9 +698,8 @@ emptySequ = Sequ (\as -> as)
 singleSequ :: a -> Sequ a
 singleSequ a = Sequ (\as -> a : as)
 
-(<>) :: Sequ a -> Sequ a -> Sequ a
-Sequ x1 <> Sequ x2 = Sequ (\as -> x1 (x2 as))
-infixr 5 <>
+appendSequ :: Sequ a -> Sequ a -> Sequ a
+appendSequ (Sequ x1) (Sequ x2) = Sequ (\as -> x1 (x2 as))
 
 seqToList :: Sequ a -> [a]
 seqToList (Sequ x) = x []
